<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	require_once(_PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkImportBase.php");
	
	/*
	 * ex. : <manufacturer ref="pick ouic"><description/></manufacturer>
	 */
	class PolarisLinkImport_manufacturer extends PolarisLinkImportBase 
	{
		public function OnInit()
		{
			parent::OnInit();
			
			$this->setCache(new PolarisLinkExtRefCache($this->Link->LinkID, "manufacturer"));
		}
		
		public function getManufacturerId($polarisRef, $name, $active = true)
		{
			return $this->getCache("pr_manufacturer")->get($polarisRef);
		}	
		
		public function getOrCreateManufacturerId($polarisRef, $name, $active = true)
		{
			$psId = $this->getCache("pr_manufacturer")->get($polarisRef);

			if (!empty($psId))
			{
				// Si on a un id, on vérifie qu'il existe toujours (problème avec certaines installation de presta!!)				
				$manufacturer = new Manufacturer($psId);
				if (!$manufacturer || $manufacturer->id != $psId)
				{
					PolarisLink::Log(LOG_WARNING, 
						sprintf('Corruption cache marque #%s : %s (cherché et non trouvé %s) détectée, écrasement !', 
							$polarisRef, $name, $psId),
						$this->Link->LinkID, null, null, true);
					$psId = 0;
					$this->getCache("pr_manufacturer")->set($polarisRef, $psId);	// suppression cache
				}
			}

			if (empty($psId))
			{
				// On cherche la marque par son nom ...
				$name = checkAttributeName($name);
				$psId = Manufacturer::getIdByName($name);
				
				if (empty($psId))
				{					
					$obj = new Manufacturer();
					$obj->name = empty($name) ? $polarisRef : $name;
					$obj->active = $active;

					$this->NewLogCtx($obj, "Création de la marque %s", [$obj->name])->LogCreate()->Commit();
					
					$psId = $obj->id;					
				}
				
				$this->getCache("pr_manufacturer")->set($polarisRef, $psId);
			}
			
			return $psId;
		}	
		
		protected function OnImportData($data)
		{
			if (!$this->Link->OPT_ALLOW_I_CATALOG)
				return;	// Rien à faire ici dans ce cas là !
			
			// Avons nous la référence Polaris ?
			$polarisRef = (string) $this->GetMandatory($data, "", "ref");

			// Localisation de la marque
			$psId = $this->getCache("pr_manufacturer")->get($polarisRef);
			
			// Activé ?
			$deleted = (string) $this->GetOptional($data, "", "deleted", "0");
			
			if (!$deleted)
			{
				$obj = new Manufacturer($this->getOrCreateManufacturerId($polarisRef, (string) $this->GetMandatory($data, "name"), false));
				$change = false;
			
				$log = $this->NewLogCtx($obj, "Modification de la marque %s", [$obj->name]);

				$this->updProperty($log, $obj, "name", $this->GetMandatory($data, "name"), "checkAttributeName");
				if ($this->Link->OPT_ALLOW_I_DESCRIPTIONS)
					$this->updOptProperty($log, $obj, "description", $data, "description");
				if ($this->Link->OPT_ALLOW_I_MDESCRIPTIONS)
					$this->updOptProperty($log, $obj, "meta_description", $data, "meta");

				$this->updProperty($log, $obj, "active", 1);
				$log->Commit();

				if ($this->Link->OPT_ALLOW_I_PHOTOS)
					$this->ImportPhotoLogo("marque", _PS_MANU_IMG_DIR_, "manufacturers", "manufacturer", $obj, (string) $data->photos);							
			}
			else if (!empty($psId))
			{
				// Element non publié mais en cours sur le site, on active ou pas, selon
				$obj = new Manufacturer($psId);

				$log = $this->NewLogCtx($obj, "Désactivation de la marque %s", [$obj->name]);
				$this->updProperty($log, $obj, "active", 0);

				$log->Commit();
			}
		}
	}
	
